"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const queryUtil = __importStar(require("../utils/query"));
const insert_item_1 = require("./insert-item");
class UpdateItem extends insert_item_1.InsertItem {
    constructor(table, dynamodb) {
        super(table, dynamodb);
    }
    /**
     * Create a conditional update item object where the condition should be satisfied in order for the item to be
     * updated. This should be used if you want to update a record but not insert one if the index does not exist.
     *
     * @param	condition           A condition that must be satisfied in order for a conditional UpdateItem to succeed.
     */
    where(condition) {
        // Parse the query
        const parsedQuery = queryUtil.parse(condition, this.params.ExpressionAttributeValues);
        if (this.params.ConditionExpression) {
            this.params.ConditionExpression = `(${this.params.ConditionExpression}) AND (${parsedQuery.ConditionExpression})`;
        }
        else {
            this.params.ConditionExpression = parsedQuery.ConditionExpression;
        }
        // Add the parsed query attributes to the correct properties of the params object
        this.params.ExpressionAttributeNames = Object.assign(Object.assign({}, this.params.ExpressionAttributeNames), parsedQuery.ExpressionAttributeNames);
        this.params.ExpressionAttributeValues = Object.assign(Object.assign({}, this.params.ExpressionAttributeValues), parsedQuery.ExpressionAttributeValues);
        // Return the object for chaining purposes
        return this;
    }
    /**
     * Builds and returns the raw DynamoDB query object.
     */
    buildRawQuery() {
        return Object.assign(Object.assign({}, this.params), { TableName: (this.table).name });
    }
    /**
     * This method will execute the update item request that was built up.
     */
    exec() {
        const db = this.dynamodb.dynamodb;
        if (!db) {
            return Promise.reject(new Error('Call .connect() before executing queries.'));
        }
        return this.runQuery(() => db.update(this.buildRawQuery()).promise())
            .then(data => {
            // Return the attributes
            return this.rawResult === true ? data : data.Attributes;
        });
    }
}
exports.UpdateItem = UpdateItem;
//# sourceMappingURL=update-item.js.map